@@ -6,63 +6,67 @@ use warnings;
 
 use base 'Exporter';
 
-# Should reflect version of the libopendmarc library
-our $VERSION = '1.00';
-
 our @EXPORT = qw( @ALL );
 
 our @ALL = qw(
-    DMARC_DNS_ERROR_NO_RECORD
+    DMARC_POLICY_NONE
     DMARC_DNS_ERROR_NXDOMAIN
+    MAXPATHLEN
     DMARC_DNS_ERROR_TMPERR
-    DMARC_FROM_DOMAIN_ABSENT
     DMARC_MAXHOSTNAMELEN
-    DMARC_PARSE_ERROR_BAD_DKIM_MACRO
-    DMARC_PARSE_ERROR_BAD_SPF_MACRO
-    DMARC_PARSE_ERROR_BAD_VALUE
+    DMARC_POLICY_SPF_OUTCOME_FAIL
+    DMARC_RECORD_FO_1
+    DMARC_RECORD_RF_AFRF
+    DMARC_RECORD_A_STRICT
+    DMARC_POLICY_SPF_ORIGIN_HELO
+    DMARC_RECORD_A_RELAXED
+    MAXNS
+    DMARC_TLD_ERROR_UNKNOWN
     DMARC_PARSE_ERROR_BAD_VERSION
+    DMARC_POLICY_DKIM_OUTCOME_FAIL
     DMARC_PARSE_ERROR_EMPTY
-    DMARC_PARSE_ERROR_NO_ALLOC
-    DMARC_PARSE_ERROR_NO_DOMAIN
-    DMARC_PARSE_ERROR_NO_REQUIRED_P
+    OPENDMARC_LIB_VERSION
+    DMARC_FROM_DOMAIN_ABSENT
     DMARC_PARSE_ERROR_NULL_CTX
+    DMARC_RECORD_P_QUARANTINE
+    DMARC_RECORD_RF_IODEF
+    DMARC_POLICY_DKIM_OUTCOME_PASS
+    DMARC_POLICY_QUARANTINE
+    DMARC_RECORD_P_NONE
+    DMARC_POLICY_DKIM_ALIGNMENT_PASS
+    DMARC_RECORD_FO_UNSPECIFIED
+    DMARC_RECORD_P_UNSPECIFIED
+    OPENDMARC_TLD_TYPE_NONE
+    DMARC_POLICY_SPF_OUTCOME_NONE
+    DMARC_POLICY_SPF_OUTCOME_TMPFAIL
     DMARC_PARSE_OKAY
+    DMARC_POLICY_SPF_OUTCOME_PASS
+    OPENDMARC_TLD_TYPE_MOZILLA
+    DMARC_PARSE_ERROR_BAD_SPF_MACRO
+    DMARC_POLICY_SPF_ALIGNMENT_FAIL
+    OPENDMARC_MAX_NSADDRLIST
+    DMARC_DNS_ERROR_NO_RECORD
+    DMARC_PARSE_ERROR_NO_ALLOC
+    DMARC_RECORD_A_UNSPECIFIED
+    DMARC_PARSE_ERROR_NO_DOMAIN
+    DMARC_RECORD_FO_S
+    DMARC_RECORD_FO_D
+    DMARC_POLICY_IP_TYPE_IPV6
+    DMARC_PARSE_ERROR_NO_REQUIRED_P
+    DMARC_POLICY_SPF_ORIGIN_MAILFROM
+    DMARC_RECORD_FO_0
     DMARC_POLICY_ABSENT
     DMARC_POLICY_DKIM_ALIGNMENT_FAIL
-    DMARC_POLICY_DKIM_ALIGNMENT_PASS
-    DMARC_POLICY_DKIM_OUTCOME_FAIL
-    DMARC_POLICY_DKIM_OUTCOME_NONE
-    DMARC_POLICY_DKIM_OUTCOME_PASS
-    DMARC_POLICY_DKIM_OUTCOME_TMPFAIL
-    DMARC_POLICY_IP_TYPE_IPV4
-    DMARC_POLICY_IP_TYPE_IPV6
-    DMARC_POLICY_NONE
-    DMARC_POLICY_PASS
-    DMARC_POLICY_QUARANTINE
-    DMARC_POLICY_REJECT
-    DMARC_POLICY_SPF_ALIGNMENT_FAIL
-    DMARC_POLICY_SPF_ALIGNMENT_PASS
-    DMARC_POLICY_SPF_ORIGIN_HELO
-    DMARC_POLICY_SPF_ORIGIN_MAILFROM
-    DMARC_POLICY_SPF_OUTCOME_FAIL
-    DMARC_POLICY_SPF_OUTCOME_NONE
-    DMARC_POLICY_SPF_OUTCOME_PASS
-    DMARC_POLICY_SPF_OUTCOME_TMPFAIL
-    DMARC_RECORD_A_RELAXED
-    DMARC_RECORD_A_STRICT
-    DMARC_RECORD_A_UNSPECIFIED
-    DMARC_RECORD_P_NONE
-    DMARC_RECORD_P_QUARANTINE
-    DMARC_RECORD_P_REJECT
-    DMARC_RECORD_P_UNSPECIFIED
-    DMARC_RECORD_RF_AFRF
-    DMARC_RECORD_RF_IODEF
     DMARC_RECORD_RF_UNSPECIFIED
-    DMARC_TLD_ERROR_UNKNOWN
-    OPENDMARC_LIB_VERSION
-    OPENDMARC_MAX_NSADDRLIST
-    OPENDMARC_TLD_TYPE_MOZILLA
-    OPENDMARC_TLD_TYPE_NONE
+    DMARC_POLICY_PASS
+    DMARC_POLICY_DKIM_OUTCOME_TMPFAIL
+    DMARC_POLICY_DKIM_OUTCOME_NONE
+    DMARC_POLICY_IP_TYPE_IPV4
+    DMARC_POLICY_SPF_ALIGNMENT_PASS
+    DMARC_PARSE_ERROR_BAD_DKIM_MACRO
+    DMARC_PARSE_ERROR_BAD_VALUE
+    DMARC_RECORD_P_REJECT
+    DMARC_POLICY_REJECT
 );
 
 1;
